@@ -2,7 +2,9 @@
 from sys import version
 import os,time,requests,json,threading
 
-class file_operations():
+__all__=["file_operations","time_class","network","text","thread"]
+
+class a():
     def __init__(self):
         pass
     def file_exists(self,path):
@@ -22,7 +24,7 @@ class file_operations():
 
     def file_name_get_suffix_name(self,fill_name):
         return fill_name.split('.')[-1]
-class time_class:
+class b():
     def __init__(self):
         pass
     def get_time(self):
@@ -30,7 +32,7 @@ class time_class:
     def time_sleep(self,stime):
         time.sleep(stime)
 
-class network():
+class c():
     def __init__(self):
         pass
     def get_url(self,url):
@@ -42,13 +44,13 @@ class network():
         for a in r.iter_content(chunk_size=100):  # iter是iter
             f.write(a)
 
-class text():
+class d():
     def __init__(self):
         pass
     def parsing_text(self,text):
         return json.load(text)
 
-class thread():
+class e():
     def __init__(self):
         pass
 
@@ -56,4 +58,11 @@ class thread():
         m = threading.Thread(target=methods, args=parameter)
         m.start()
 
+file_operations = a()
+time_class = b()
+network = c()
+text = d()
+thread = e()
+
+
 print("Multifunction 0.0.3 (Python",version,")")
\ No newline at end of file
